==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPivotGridDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarDescriptionMetadata } from "./WebGridToolbarDescriptionMetadata";
import { WebGridToolbarActionsDescriptionMetadata } from "./WebGridToolbarActionsDescriptionMetadata";
import { WebGridToolbarTitleDescriptionMetadata } from "./WebGridToolbarTitleDescriptionMetadata";
import { WebGridToolbarExporterDescriptionMetadata } from "./WebGridToolbarExporterDescriptionMetadata";
import { WebGridToolbarHidingDescriptionMetadata } from "./WebGridToolbarHidingDescriptionMetadata";
import { WebGridToolbarPinningDescriptionMetadata } from "./WebGridToolbarPinningDescriptionMetadata";
import { WebGridToolbarAdvancedFilteringDescriptionMetadata } from "./WebGridToolbarAdvancedFilteringDescriptionMetadata";
import { WebGridToolbarBaseActionDescriptionMetadata } from "./WebGridToolbarBaseActionDescriptionMetadata";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebPivotConfigurationDescriptionMetadata } from "./WebPivotConfigurationDescriptionMetadata";
import { WebDimensionsChangeEventArgsDescriptionMetadata } from "./WebDimensionsChangeEventArgsDescriptionMetadata";
import { WebPivotConfigurationChangedEventArgsDescriptionMetadata } from "./WebPivotConfigurationChangedEventArgsDescriptionMetadata";
import { WebPivotDimensionEventArgsDescriptionMetadata } from "./WebPivotDimensionEventArgsDescriptionMetadata";
import { WebPivotValueEventArgsDescriptionMetadata } from "./WebPivotValueEventArgsDescriptionMetadata";
import { WebSortingExpressionEventArgsDescriptionMetadata } from "./WebSortingExpressionEventArgsDescriptionMetadata";
import { WebValuesChangeEventArgsDescriptionMetadata } from "./WebValuesChangeEventArgsDescriptionMetadata";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebPivotGridDescription } from "./WebPivotGridDescription";
/**
 * @hidden
 */
var WebPivotGridDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridDescriptionMetadata, _super);
    function WebPivotGridDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotGridDescriptionMetadata.b = function (a) {
        if (WebPivotGridDescriptionMetadata.a == null) {
            WebPivotGridDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotGridDescriptionMetadata.c(WebPivotGridDescriptionMetadata.a);
        }
        if (a.k(WebPivotGridDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPivotGridDescriptionMetadata.a);
        WebPivotGridDescriptionMetadata.f(a);
        WebPivotConfigurationDescriptionMetadata.d(a);
        WebDimensionsChangeEventArgsDescriptionMetadata.d(a);
        WebPivotConfigurationChangedEventArgsDescriptionMetadata.d(a);
        WebPivotDimensionEventArgsDescriptionMetadata.d(a);
        WebPivotValueEventArgsDescriptionMetadata.d(a);
        WebSortingExpressionEventArgsDescriptionMetadata.d(a);
        WebValuesChangeEventArgsDescriptionMetadata.d(a);
    };
    WebPivotGridDescriptionMetadata.c = function (a) {
        WebGridBaseDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PivotGrid");
        a.item("__tagNameWC", "String:igc-pivot-grid");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
        a.item("ValueChipTemplateRef", "(w:ValueChipTemplate,wf:ValueChipTemplate)TemplateRef::object");
        a.item("PivotConfiguration", "ExportedType:WebPivotConfiguration");
        a.item("PivotConfiguration@mustSetInCode", "WebComponents;Blazor");
        a.item("ShowPivotConfigurationUI", "Boolean");
        a.item("SuperCompactMode", "Boolean");
        a.item("DefaultExpandState", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef::object");
        a.item("EmptyPivotGridTemplateRef", "(w:EmptyPivotGridTemplate,wf:EmptyPivotGridTemplate)TemplateRef::object");
        a.item("DimensionsChangeRef", "EventRef::dimensionsChange:customEvent");
        a.item("PivotConfigurationChangeRef", "EventRef::pivotConfigurationChange:customEvent");
        a.item("DimensionInitRef", "EventRef::dimensionInit:customEvent");
        a.item("ValueInitRef", "EventRef::valueInit:customEvent");
        a.item("DimensionsSortingExpressionsChangeRef", "EventRef::dimensionsSortingExpressionsChange:customEvent");
        a.item("ValuesChangeRef", "EventRef::valuesChange:customEvent");
        WebPivotGridDescriptionMetadata.e(a);
    };
    WebPivotGridDescriptionMetadata.d = function (a) {
        WebPivotGridDescriptionMetadata.b(a);
        a.ad("WebPivotGrid", function () { return new WebPivotGridDescription(); });
        a.ac("WebPivotGrid", WebPivotGridDescriptionMetadata.a);
    };
    WebPivotGridDescriptionMetadata.e = function (a) {
        a.item("__deferAttachWC", "Boolean");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
    };
    WebPivotGridDescriptionMetadata.f = function (a) {
        WebGridToolbarDescriptionMetadata.d(a);
        WebGridToolbarActionsDescriptionMetadata.d(a);
        WebGridToolbarTitleDescriptionMetadata.d(a);
        WebGridToolbarExporterDescriptionMetadata.d(a);
        WebGridToolbarHidingDescriptionMetadata.d(a);
        WebGridToolbarPinningDescriptionMetadata.d(a);
        WebGridToolbarAdvancedFilteringDescriptionMetadata.d(a);
        WebGridToolbarBaseActionDescriptionMetadata.d(a);
        WebGridToolbarContentDescriptionMetadata.d(a);
    };
    WebPivotGridDescriptionMetadata.$t = markType(WebPivotGridDescriptionMetadata, 'WebPivotGridDescriptionMetadata');
    WebPivotGridDescriptionMetadata.a = null;
    return WebPivotGridDescriptionMetadata;
}(Base));
export { WebPivotGridDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebPivotGridDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarDescriptionMetadata } from "./WebGridToolbarDescriptionMetadata";
import { WebGridToolbarActionsDescriptionMetadata } from "./WebGridToolbarActionsDescriptionMetadata";
import { WebGridToolbarTitleDescriptionMetadata } from "./WebGridToolbarTitleDescriptionMetadata";
import { WebGridToolbarExporterDescriptionMetadata } from "./WebGridToolbarExporterDescriptionMetadata";
import { WebGridToolbarHidingDescriptionMetadata } from "./WebGridToolbarHidingDescriptionMetadata";
import { WebGridToolbarPinningDescriptionMetadata } from "./WebGridToolbarPinningDescriptionMetadata";
import { WebGridToolbarAdvancedFilteringDescriptionMetadata } from "./WebGridToolbarAdvancedFilteringDescriptionMetadata";
import { WebGridToolbarBaseActionDescriptionMetadata } from "./WebGridToolbarBaseActionDescriptionMetadata";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebPivotConfigurationDescriptionMetadata } from "./WebPivotConfigurationDescriptionMetadata";
import { WebPivotUISettingsDescriptionMetadata } from "./WebPivotUISettingsDescriptionMetadata";
import { WebDimensionsChangeEventArgsDescriptionMetadata } from "./WebDimensionsChangeEventArgsDescriptionMetadata";
import { WebPivotConfigurationChangedEventArgsDescriptionMetadata } from "./WebPivotConfigurationChangedEventArgsDescriptionMetadata";
import { WebPivotDimensionEventArgsDescriptionMetadata } from "./WebPivotDimensionEventArgsDescriptionMetadata";
import { WebPivotValueEventArgsDescriptionMetadata } from "./WebPivotValueEventArgsDescriptionMetadata";
import { WebSortingExpressionEventArgsDescriptionMetadata } from "./WebSortingExpressionEventArgsDescriptionMetadata";
import { WebValuesChangeEventArgsDescriptionMetadata } from "./WebValuesChangeEventArgsDescriptionMetadata";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebPivotGridDescription } from "./WebPivotGridDescription";
/**
 * @hidden
 */
var WebPivotGridDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridDescriptionMetadata, _super);
    function WebPivotGridDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotGridDescriptionMetadata.b = function (a) {
        if (WebPivotGridDescriptionMetadata.a == null) {
            WebPivotGridDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotGridDescriptionMetadata.c(WebPivotGridDescriptionMetadata.a);
        }
        if (a.k(WebPivotGridDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPivotGridDescriptionMetadata.a);
        WebPivotGridDescriptionMetadata.f(a);
        WebPivotConfigurationDescriptionMetadata.d(a);
        WebPivotUISettingsDescriptionMetadata.d(a);
        WebDimensionsChangeEventArgsDescriptionMetadata.d(a);
        WebPivotConfigurationChangedEventArgsDescriptionMetadata.d(a);
        WebPivotDimensionEventArgsDescriptionMetadata.d(a);
        WebPivotValueEventArgsDescriptionMetadata.d(a);
        WebSortingExpressionEventArgsDescriptionMetadata.d(a);
        WebValuesChangeEventArgsDescriptionMetadata.d(a);
    };
    WebPivotGridDescriptionMetadata.c = function (a) {
        WebGridBaseDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PivotGrid");
        a.item("__tagNameWC", "String:igc-pivot-grid");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
        a.item("ValueChipTemplateRef", "(w:ValueChipTemplate,wf:ValueChipTemplate)TemplateRef::object");
        a.item("RowDimensionHeaderTemplateRef", "(w:RowDimensionHeaderTemplate,wf:RowDimensionHeaderTemplate)TemplateRef::object");
        a.item("PivotConfiguration", "ExportedType:WebPivotConfiguration");
        a.item("PivotConfiguration@mustSetInCode", "WebComponents;Blazor;React");
        a.item("AutoGenerateConfig", "Boolean");
        a.item("PivotUI", "ExportedType:WebPivotUISettings");
        a.item("SuperCompactMode", "Boolean");
        a.item("DefaultExpandState", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef::object");
        a.item("EmptyPivotGridTemplateRef", "(w:EmptyPivotGridTemplate,wf:EmptyPivotGridTemplate)TemplateRef::object");
        a.item("DimensionsChangeRef", "EventRef::dimensionsChange:customEvent");
        a.item("PivotConfigurationChangeRef", "EventRef::pivotConfigurationChange:customEvent");
        a.item("DimensionInitRef", "EventRef::dimensionInit:customEvent");
        a.item("ValueInitRef", "EventRef::valueInit:customEvent");
        a.item("DimensionsSortingExpressionsChangeRef", "EventRef::dimensionsSortingExpressionsChange:customEvent");
        a.item("ValuesChangeRef", "EventRef::valuesChange:customEvent");
        WebPivotGridDescriptionMetadata.e(a);
    };
    WebPivotGridDescriptionMetadata.d = function (a) {
        WebPivotGridDescriptionMetadata.b(a);
        a.ae("WebPivotGrid", function () { return new WebPivotGridDescription(); });
        a.ad("WebPivotGrid", WebPivotGridDescriptionMetadata.a);
    };
    WebPivotGridDescriptionMetadata.e = function (a) {
        a.item("__deferAttachWC", "Boolean");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
    };
    WebPivotGridDescriptionMetadata.f = function (a) {
        WebGridToolbarDescriptionMetadata.d(a);
        WebGridToolbarActionsDescriptionMetadata.d(a);
        WebGridToolbarTitleDescriptionMetadata.d(a);
        WebGridToolbarExporterDescriptionMetadata.d(a);
        WebGridToolbarHidingDescriptionMetadata.d(a);
        WebGridToolbarPinningDescriptionMetadata.d(a);
        WebGridToolbarAdvancedFilteringDescriptionMetadata.d(a);
        WebGridToolbarBaseActionDescriptionMetadata.d(a);
        WebGridToolbarContentDescriptionMetadata.d(a);
    };
    WebPivotGridDescriptionMetadata.$t = markType(WebPivotGridDescriptionMetadata, 'WebPivotGridDescriptionMetadata');
    WebPivotGridDescriptionMetadata.a = null;
    return WebPivotGridDescriptionMetadata;
}(Base));
export { WebPivotGridDescriptionMetadata };
